@@ -1,6 +1,6 @@
 =head1 NAME
 
-Date::Tolkien::Shire.pm
+Date::Tolkien::Shire - Convert dates into the Shire Calendar.
 
 =head1 DESCRIPTION
 
@@ -20,9 +20,26 @@ am curious to see how this gets used (if it gets used that is).
 
 Tom Braun <tbraun@pobox.com>
 
-=head1 DATE
+Thomas R. Wyant, III F<wyant at cpan dot org>
 
-February 2001
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2001-2003, 2006 Tom Braun. All rights reserved.
+
+Copyright (C) 2017 Thomas R. Wyant, III
+
+The calendar implemented on this module was created by J.R.R. Tolkien,
+and the copyright is still held by his estate.  The license and
+copyright given herein applies only to this code and not to the
+calendar itself.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. For more details, see the full text
+of the licenses in the directory LICENSES.
+
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =cut
 
@@ -33,7 +50,7 @@ use Time::Local;
 
 use vars qw($VERSION $ERROR);
 
-$VERSION = 1.12;
+$VERSION = '1.20';
 
 =head1 METHOD REFERENCE
 
@@ -569,7 +586,7 @@ sub on_date {
     # the day matches up
     $events{0} = { 3  => "Wedding of King Elessar and Arwen, 1419.\n"
 		   };
-    $events{1} = { 8  => "The Company of the Ring reaches Holland, 1419.\n",
+    $events{1} = { 8  => "The Company of the Ring reaches Hollin, 1419.\n",
 		   13 => "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n",
 		   14 => "The Company of the Ring spends the night in Moria hall 21, 1419.\n",
 		   15 => "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n",
@@ -591,7 +608,7 @@ sub on_date {
 		       "Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.\n" .
 		       "Frodo and Samwise enter the eastern Emyn Muil, 1419.\n",
 		   27 => "Aragorn reaches the west-cliff at sunrise, 1419.\n" .
-		       "Eomer sets out Eastfold against Theoden's orders to pursue the Orcs, 1419.\n",
+		       "Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.\n",
 		   28 => "Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.\n",
 		   29 => "Meriodoc and Pippin escape and meet Treebeard, 1419.\n" .
 		       "The Rohirrim attack at sunrise and destroy the Orcs, 1419.\n" .
@@ -625,7 +642,7 @@ sub on_date {
 		   11 => "Gollum visits Shelob, 1419.\n" . 
 		       "Denethor sends Faramir to Osgiliath, 1419.\n" .
 		       "Eastern Rohan is invaded and Lorien assaulted, 1419.\n",
-		   12 => "Gollum leads Frodo in Shelob's lair, 1419.\n" .
+		   12 => "Gollum leads Frodo into Shelob's lair, 1419.\n" .
 		       "Ents defeat the invaders of Rohan, 1419.\n",
 		   13 => "Frodo captured by the Orcs of Cirith Ungol, 1419.\n" .
 		       "The Pelennor is overrun and Faramir is wounded, 1419.\n" .
@@ -652,7 +669,7 @@ sub on_date {
 		   27 => "Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.\n",
 		   28 => "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n"
 		   };
-    $events{4} = { 6  => "The mallorn trea flowers in the party field, 1420.\n",
+    $events{4} = { 6  => "The mallorn tree flowers in the party field, 1420.\n",
 	           8  => "Ring bearers are honored on the fields of Cormallen, 1419.\n",
 	           12 => "Gandalf arrives in Hobbiton, 1418\n"
 	           };
@@ -669,7 +686,7 @@ sub on_date {
     $events{8} = { 10 => "Funeral of King Theoden, 1419.\n"
 		   };
     $events{9} = { 18 => "Gandalf escapes from Orthanc in the early hours, 1418.\n",
-		   19 => "Gandalf comes to Edoras as a beggar, and is refused admintance, 1418",
+		   19 => "Gandalf comes to Edoras as a beggar, and is refused admittance, 1418",
 		   20 => "Gandalf gains entrance to Edoras.  Theoden commands him to go:\n" .
 		       "\"Take any horse, only be gone ere tomorrow is old\", 1418.\n",
 		   21 => "The hobbits return to Rivendell, 1419.\n",
@@ -678,7 +695,7 @@ sub on_date {
 		       "  they drive off the guard of Rangers, 1418.\n" .
 		       "Saruman comes to the Shire, 1419.\n",   
 		   23 => "Four Black Riders enter the shire before dawn.  The others pursue \n" .
-		       "the Rangers eastword and then return to watch the Greenway, 1418.\n" .
+		       "the Rangers eastward and then return to watch the Greenway, 1418.\n" .
 		       "A Black Rider comes to Hobbiton at nightfall, 1418.\n" . 
 		       "Frodo leaves Bag End, 1418.\n" .
 		       "Gandalf having tamed Shadowfax rides from Rohan, 1418.\n",
@@ -692,7 +709,7 @@ sub on_date {
             	   };
     $events{10} = { 3  => "Gandalf attacked at night on Weathertop, 1418.\n",
 		    5  => "Gandalf and the Hobbits leave Rivendell, 1419.\n",
-		    6  => "The camp under weathertop is attacked at night and Frodo is wounded, 1418.\n",
+		    6  => "The camp under Weathertop is attacked at night and Frodo is wounded, 1418.\n",
 		    11 => "Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.\n",
 		    13 => "Frodo crosses the Bridge of Mitheithel, 1418.\n",
 		    18 => "Glorfindel finds Frodo at dusk, 1418.\n" . 
@@ -706,7 +723,7 @@ sub on_date {
     $events{11} = { 3  => "Battle of Bywater and passing of Saruman, 1419.\n" .
 			"End of the War of the Ring, 1419.\n"
 		  };
-    $events{12} = { 25 => "The Company of the Ring leaves Rivendell at dusk.\n"
+    $events{12} = { 25 => "The Company of the Ring leaves Rivendell at dusk, 1418.\n"
 		    };
 
     if ($self->{holiday} and defined($events{0}->{$self->{holiday}})) {
@@ -724,7 +741,7 @@ sub on_date {
 
 =head1 NOTE: YEAR CALCULATION
 
-http://www.glyhweb.com/arda/f/fourthage.html references a letter sent by
+L<http://www.glyhweb.com/arda/f/fourthage.html> references a letter sent by
 Tolkien in 1958 in which he estimates approxiimately 6000 years have passed
 since the War of the Ring and the end of the Third Age.  (Thanks to Danny
 O'Brien from sending me this link).  I took this approximate as an exact
@@ -750,10 +767,10 @@ the two calendars, however.  Thus the last day of our year is sometimes
 
 =head1 BIBLIOGRAPHY
 
-Tolkien, J. R. R. <i>Return of the King<i>.  New York: Houghton Mifflin Press,
+Tolkien, J. R. R. I<Return of the King>.  New York: Houghton Mifflin Press,
 1955.
 
-http://www.glyphweb.com/arda/f/fourthage.html
+L<http://www.glyphweb.com/arda/f/fourthage.html>
 
 =head1 BUGS
 
@@ -766,3 +783,5 @@ support on your system.
 =cut
 
 1;
+
+# ex: set textwidth=72 :
